==> dispmua_1.6.8.orig.tar.bz2: dispmua-1.6.8/chrome/chrome.jar!/content/data-73.js <==
dispMUA.arDispMUAAllocation["s"] =
{
  "schalk&friends powered by htmlmimemail" : [ "phpguru_org.png" , "http://www.phpguru.org/" ] ,
  "sendnewsletter/parallel by epublica" : [ "epublica.png" , "http://www.epublica.de/" ] ,
  "smarttools publishing serienmailer" : [ "smarttools.png" , "http://www.smarttools.de/" ] ,
  "site web lyonnaise des eaux france" : [ "lyonnaise-des-eaux.png" , "http://www.lyonnaise-des-eaux.fr/" ] ,
  "suse linux openexchange server" : [ "suse.png" , "http://www.suse.com/" ] ,
  "sun one messenger express" : [ "sun_one.png" , "http://www.sun.com/" ] ,
  "smtp client for ibm i5/os" : [ "i5-os.png" , "http://www.ibm.com/" ] ,
  "smtp client for ibm as400" : [ "ibm.png" , "http://www.ibm.com/" ] ,
  "symon registration robot" : [ "symon.png" , "http://www.symon.ru/" ] ,
  "spiegel verlag webmailer" : [ "spiegel_online.png" , "http://www.spiegel.de/" ] ,
  "seven enterprise gateway" : [ "seven.png" , "http://www.seven.com/" ] ,
  "synck graphica mailform" : [ "synck-graphica-mailform.png" , "http://www.synck.com/contents/download/cgi-perl/mailformpro.html" ] ,
  "samlogic mailing system" : [ "samlogic_mailing_system.png" , "http://www.samlogic.net/multimailer/multimailer.htm" ] ,
  "striata communications" : [ "striata.png" , "http://www.striata.com/" ] ,
  "sevactivex smtp mailer" : [ "sev.png" , "http://www.tools4vb.com/" ] ,
  "sun outlook connector" : [ "sun_outlook.png" , "http://www.sun.com/" ] ,
  "subculture newsletter" : [ "subculture.png" , "http://www.subculture.de/" ] ,
  "steinbrecher software" : [ "steinbrecher.png" , "http://www.steinbrecher-software.de/" ] ,
  "spifforific thinkgeek" : [ "thinkgeek.png" , "http://www.thinkgeek.com/" ] ,
  "software: swoppen.com" : [ "swoppen.png" , "http://www.swoppen.com/" ] ,
  "stress-free contact" : [ "stressfreecontact.png" , "http://www.stressfreecontact.com/" ] ,
  "speedbone-webmailer" : [ "speedbone.png" , "http://www.speedbone.de/" ] ,
  "surfino newsreader" : [ "surfino.png" , "http://newsreader.surfino.com/" ] ,
  "sesec java webmail" : [ "sesec-webmail.png" , "http://sesec.ma.gov.br/" ] ,
  "saunalahti webmail" : [ "saunalahti_fi.png" , "http://www.saunahahti.fi/" ] ,
  "supermailerscript" : [ "supermailerscript.png" , "http://www.supermailer.de/" ] ,
  "stroede cmartpost" : [ "stroede-ralton.png" , "http://www.stroederalton.se/" ] ,
  "sse-unimatrix-one" : [ "1und1.png" , "http://www.1and1.co.uk/" ] ,
  "smartresponder.ru" : [ "smartresponder_ru.png" , "http://www.smartresponder.ru/" ] ,
  "stepstone mailer" : [ "stepstone.png" , "http://www.stepstone.de/" ] ,
  "sav materiel.net" : [ "materiel.png" , "http://www.materiel.net/" ] ,
  "spritmonitor.de" : [ "spritmonitor.png" , "http://www.spritmonitor.de/" ] ,
  "sonicmailer pro" : [ "sonicmailer_pro.png" , "http://www.triexa.com/" ] ,
  "share-rapid.com" : [ "share-rapid.png" , "http://share-rapid.com/" ] ,
  "scooby for beos" : [ "beos_scooby.png" , "http://sourceforge.net/projects/scooby" ] ,
  "satamatics ssas" : [ "satamatics.png" , "http://www.satamatics.com/ssas/" ] ,
  "swistak mailer" : [ "swistak.png" , "http://www.swistak.pl/" ] ,
  "smartstore.biz" : [ "smartstore.png" , "http://www.smartstore.com/" ] ,
  "sky-newsletter" : [ "sky-scripts.png" , "http://www.sky-scripts.de/" ] ,
  "sibnet webmail" : [ "sibnet.png" , "http://mail.sibnet.ru/" ] ,
  "sevsmtp mailer" : [ "sev.png" , "http://www.tools4vb.com/" ] ,
  "scouts on-line" : [ "scouts-online.png" , "http://www.scouting.nl/" ] ,
  "sharpener mail" : [ "sharpener.png" , "http://www.sharpener.com.br/" ] ,
  "sysaid server" : [ "sysaid.png" , "http://www.ilient.com/" ] ,
  "store-mailer/" : [ "apple_store.png" , "http://store.apple.com/" ] ,
  "sohu web mail" : [ "sohu_com.png" , "http://www.sohu.com/" ] ,
  "sina freemail" : [ "sina_com.png" , "http://mail.sina.com.cn/" ] ,
  "system2teach" : [ "hs-fulda.png" , "http://www.system2teach.de/" ] ,
  "synergyemail" : [ "synergyemail.png" , "http://www.synergysitemanager.com/" ] ,
  "synchredible" : [ "synchredible.png" , "http://www.ascomp.de/index.php?php=products" ] ,
  "startaid.com" : [ "startaid_com.png" , "http://www.startaid.com/" ] ,
  "snood letter" : [ "snood.png" , "http://www.snoodworld.com/" ] ,
  "smartmessage" : [ "smartmessage.png" , "http://www.smartmessage.com.tr/" ] ,
  "staroffice21" : [ "staroffice21.png" , "http://www.nec.co.jp/gw/" ] ,
  "squirrelmail" : [ "squirrelmail.png" , "http://www.squirrelmail.org/" ] ,
  "spon-webmail" : [ "spiegel_online.png" , "http://www.spiegel.de/" ] ,
  "smtpjavamail" : [ "smtpjavamail.png" , "http://java.sun.com/products/javamail/" ] ,
  "sina webmail" : [ "sina_com.png" , "http://mail.sina.com.cn/" ] ,
  "simorganizer" : [ "simorganizer.png" ] ,
  "shop to date" : [ "shoptodate.png" , "http://www.shoptodate.de/" ] ,
  "serendipity/" : [ "serendipity.png" , "http://www.s9y.org/" ] ,
  "send::around" : [ "sendaround.png" , "http://www.sendaround.de/" ] ,
  "scrubby mail" : [ "scrubtheweb.png" , "http://www.scrubtheweb.com/" ] ,
  "syncbackpro" : [ "syncbackpro.png" , "http://www.2brightsparks.com/syncback/sbpro.html" ] ,
  "svn::notify" : [ "subversion.png" , "http://subversion.tigris.org/" ] ,
  "surveygizmo" : [ "surveygizmo.png" , "http://www.surveygizmo.com/" ] ,
  "surfcontrol" : [ "surfcontrol.png" , "http://www.surfcontrol.com/Default.aspx?id=357" ] ,
  "stumbleupon" : [ "stumbleupon.png" , "http://www.stumbleupon.com/" ] ,
  "streamserve" : [ "streamserve.png" , "http://www.streamserve.com/" ] ,
  "storeforyou" : [ "storeforyou.png" , "http://www.storeforyou.de/" ] ,
  "steg-mailer" : [ "stegcomputer.png" , "http://www.stegcomputer.ch/" ] ,
  "sqli mailer" : [ "sqli_com.png" , "http://www.sqli.com/" ] ,
  "specmanager" : [ "acdlabs.png" , "http://www.acdlabs.com/products/spec_lab/exp_spectra/" ] ,
  "spartoo.com" : [ "spartoo_com.png" , "http://www.spartoo.com/" ] ,
  "software602" : [ "software602.png" , "http://www.software602.com/" ] ,
  "snappermail" : [ "snappermail.png" , "http://www.snappermail.com/" ] ,
  "smartagent/" : [ "smartagent.png" ] ,
  "simplecheck" : [ "simplecheck.png" , "http://sourceforge.net/projects/simplecheck/" ] ,
  "simple mail" : [ "simple-mail.png" , "http://telega.phpnet.us/simplemail/" ] ,
  "shopexpress" : [ "shopexpress.png" , "http://www.shopexpress.info" ] ,
  "sendblaster" : [ "sendblaster.png" , "http://www.sendblaster.com/" ] ,
  "sa-smtpmail" : [ "softartisans.png" , "http://www.aspstudio.com/" ] ,
  "symbian os" : [ "symbian_os.png" , "http://www.symbian.com/" ] ,
  "su-webmail" : [ "stockholm_uni.png" , "http://www.su.se/" ] ,
  "subskrypcj" : [ "subskrypcj.png" , "http://www.subskrypcja.pl/" ] ,
  "strongmail" : [ "strongmail.png" , "http://www.strongmail.com/" ] ,
  "stringdata" : [ "post_sk.png" , "http://www.post.sk/" ] ,
  "streamsend" : [ "streamsend.png" , "http://www.streamsend.com/" ] ,
  "step ahead" : [ "stepahead.png" , "http://www.stepahead.info/" ] ,
  "staroffice" : [ "staroffice.png" , "http://www.sun.com/software/staroffice/" ] ,
  "soupermail" : [ "soupermail.png" , "http://soupermail.sourceforge.net/" ] ,
  "smtpit pro" : [ "smtpit-pro.png" , "http://www.cnsplug-ins.com/products.htm?product=smtpit%20pro" ] ,
  "smtpbeamer" : [ "smtpbeamer.png" , "http://www.dataenter.co.at/products/smtpbeamer.htm" ] ,
  "smoothwall" : [ "smoothwall.png" , "http://www.smoothwall.net/" ] ,
  "smartmail(" : [ "freebit.png" , "http://www.freebit.com/" ] ,
  "simplemail" : [ "python.png" , "http://www.python-forum.de/post-18144.html" ] ,
  "schuelervz" : [ "schuelervz.png" , "http://schuelervz.net/" ] ,
  "scenario m" : [ "scenario-m_de.png" , "http://www.scenario-m.de/" ] ,
  "satamatics" : [ "satamatics.png" , "http://www.satamatics.com/" ] ,
  "synckolab" : [ "kolab.png" , "http://www.kolab.org/" ] ,
  "swreg.org" : [ "swreg_org.png" , "http://swreg.org/" ] ,
  "swiftdove" : [ "swiftdove.png" , "http://swiftweasel.tuxfamily.org/" ] ,
  "svnmailer" : [ "subversion.png" , "http://opensource.perlig.de/svnmailer/" ] ,
  "spnetmail" : [ "spiegel_online.png" , "http://www.spiegel.de/" ] ,
  "spicebird" : [ "spicebird.png" , "http://www.spicebird.com/" ] ,
  "speedmail" : [ "speedmail.png" , "http://members.aol.com/toadbee/Programs.htm" ] ,
  "smart4web" : [ "smart4web.png" , "http://www.smart4web.cz/" ] ,
  "sendemail" : [ "sendemail.png" , "http://caspian.dotconf.net/menu/Software/SendEmail/" ] ,
  "sake mail" : [ "sake_mail.png" , "http://www.endymion.com/products/sake/" ] ,
  "syndmail" : [ "redclay.png" , "http://www.redclay.com/products/syndmail.html" ] ,
  "symantec" : [ "symantec.png" , "http://www.symantec.com/" ] ,
  "sylpheed" : [ "sylpheed.png" , "http://sylpheed.sraoss.jp/en/" ] ,
  "sun java" : [ "java.png" , "http://www.sun.com/" ] ,
  "steganos" : [ "steganos.png" , "http://www.steganos.com/" ] ,
  "stardoll" : [ "stardoll.png" , "http://www.stardoll.com/" ] ,
  "spaps.de" : [ "spaps_de.png" , "http://www.spaps.de/" ] ,
  "sogomail" : [ "sogomail.png" , "http://sogo.opengroupware.org/" ] ,
  "socratos" : [ "socratos.png" , "http://www.socratos.be/" ] ,
  "smtpsend" : [ "smtpsend.png" , "http://www.geocities.com/mdrapps/smtpsend/" ] ,
  "smtpmail" : [ "smtpmail.png" , "http://fileup.softartisans.com/fileup-276.aspx" ] ,
  "sitemail" : [ "sitemail.png" , "http://sitemail.hostway.com/" ] ,
  "sinamail" : [ "sina_com.png" , "http://mail.sina.com.cn/" ] ,
  "sev.mail" : [ "sev.png" , "http://www.tools4vb.com/software/sevmail.php" ] ,
  "sendsmtp" : [ "sendsmtp.png" , "http://www.greyware.com/software/sendsmtp/" ] ,
  "sendmail" : [ "sendmail.png" , "http://www.sendmail.org/" ] ,
  "synapse" : [ "synapse.png" , "http://synapse.ararat.cz/" ] ,
  "swwwing" : [ "swwwing.png" , "http://www.swwwing.com/" ] ,
  "sunmail" : [ "sunmail.png" , "http://www.sunmail.com/" ] ,
  "suite26" : [ "suite26.png" , "http://www.26.co.uk/" ] ,
  "studivz" : [ "studivz.png" , "http://studivz.net/" ] ,
  "spiral/" : [ "spiral.png" , "http://www.smp.ne.jp/" ] ,
  "soom.cz" : [ "soom_cz.png" , "http://www.soom.cz/index.php?name=projects/mail/main" ] ,
  "sndmail" : [ "sndmail.png" , "http://www.xmailserver.org/davide.html" ] ,
  "si.mail" : [ "si_mail.png" , "http://www.simail.si/" ] ,
  "sybase" : [ "sybase.png" , "http://www.sybase.com/" ] ,
  "swi.hu" : [ "swi.png" , "http://www.swi.hu/" ] ,
  "strato" : [ "strato.png" , "http://www.strato.de/" ] ,
  "sophos" : [ "sophos.png" , "http://www.sophos.com/" ] ,
  "smtpit" : [ "smtpit.png" , "http://www.cnsplug-ins.com/products.htm?product=SMTPit" ] ,
  "skyrix" : [ "skyrix.png" , "http://www.skyrix.com/" ] ,
  "sixcms" : [ "six.png" , "http://www.six.de/" ] ,
  "siebel" : [ "oracle.png" , "http://www.oracle.com/siebel" ] ,
  "sidoko" : [ "siegel-edv_de.png" , "http://www.siegel-edv.de/" ] ,
  "scsmtp" : [ "sc-resources.png" , "http://www.sc-resources.net/" ] ,
  "scalix" : [ "scalix.png" , "http://www.scalix.com/" ] ,
  "sympa" : [ "sympa.png" , "http://www.sympa.org/" ] ,
  "swift" : [ "swiftmailer.png" , "http://www.swiftmailer.org/" ] ,
  "swaks" : [ "swaks.png" , "http://jetmore.org/john/code/#swaks" ] ,
  "sumo/" : [ "sumo.png" ] ,
  "smtpc" : [ "smtpc.png" , "http://shellscripts.org/project/smtpc" ] ,
  "smail" : [ "smail.png" , "http://www.weird.com/~woods/projects/smail.html" ] ,
  "slrn/" : [ "slrn.png" , "http://slrn.sourceforge.net/" ] ,
  "slrn " : [ "slrn.png" , "http://slrn.sourceforge.net/" ] ,
  "sharp" : [ "sharp.png" , "http://www.sharp.co.jp/" ] ,
  "setia" : [ "setia.png" , "http://www.setia.info/" ] ,
  "sesna" : [ "sesna.png" , "http://maple.snowdrift.cc/?sesna%2FV2" ] ,
  "sup/" : [ "ruby.png" , "http://sup.rubyforge.org/" ] ,
  "sap " : [ "sap.png" , "http://www.sap.com/" ] ,
  "smf" : [ "simplemachines.png" , "http://www.simplemachines.org/" ] ,
  "sk " : [ "typo3.png" , "http://www.sk-typo3.de/" ] ,
}

==> dispmua_1.6.9.orig.tar.bz2: dispmua-1.6.9/chrome/chrome.jar!/content/data-73.js <==
dispMUA.arDispMUAAllocation["s"] =
{
  "schalk&friends powered by htmlmimemail" : [ "phpguru_org.png" , "http://www.phpguru.org/" ] ,
  "sylvia sackwitz fotografie [sf] mail" : [ "ssf_mail.png" , "http://www.sackwitz-fotografie.de/" ] ,
  "sendnewsletter/parallel by epublica" : [ "epublica.png" , "http://www.epublica.de/" ] ,
  "smarttools publishing serienmailer" : [ "smarttools.png" , "http://www.smarttools.de/" ] ,
  "site web lyonnaise des eaux france" : [ "lyonnaise-des-eaux.png" , "http://www.lyonnaise-des-eaux.fr/" ] ,
  "suse linux openexchange server" : [ "suse.png" , "http://www.suse.com/" ] ,
  "sun one messenger express" : [ "sun_one.png" , "http://www.sun.com/" ] ,
  "smtp client for ibm i5/os" : [ "i5-os.png" , "http://www.ibm.com/" ] ,
  "smtp client for ibm as400" : [ "ibm.png" , "http://www.ibm.com/" ] ,
  "symon registration robot" : [ "symon.png" , "http://www.symon.ru/" ] ,
  "spiegel verlag webmailer" : [ "spiegel_online.png" , "http://www.spiegel.de/" ] ,
  "seven enterprise gateway" : [ "seven.png" , "http://www.seven.com/" ] ,
  "synck graphica mailform" : [ "synck-graphica-mailform.png" , "http://www.synck.com/contents/download/cgi-perl/mailformpro.html" ] ,
  "samlogic mailing system" : [ "samlogic_mailing_system.png" , "http://www.samlogic.net/multimailer/multimailer.htm" ] ,
  "striata communications" : [ "striata.png" , "http://www.striata.com/" ] ,
  "sevactivex smtp mailer" : [ "sev.png" , "http://www.tools4vb.com/" ] ,
  "sun outlook connector" : [ "sun_outlook.png" , "http://www.sun.com/" ] ,
  "subculture newsletter" : [ "subculture.png" , "http://www.subculture.de/" ] ,
  "steinbrecher software" : [ "steinbrecher.png" , "http://www.steinbrecher-software.de/" ] ,
  "spifforific thinkgeek" : [ "thinkgeek.png" , "http://www.thinkgeek.com/" ] ,
  "software: swoppen.com" : [ "swoppen.png" , "http://www.swoppen.com/" ] ,
  "stress-free contact" : [ "stressfreecontact.png" , "http://www.stressfreecontact.com/" ] ,
  "speedbone-webmailer" : [ "speedbone.png" , "http://www.speedbone.de/" ] ,
  "surfino newsreader" : [ "surfino.png" , "http://newsreader.surfino.com/" ] ,
  "sesec java webmail" : [ "sesec-webmail.png" , "http://sesec.ma.gov.br/" ] ,
  "saunalahti webmail" : [ "saunalahti_fi.png" , "http://www.saunahahti.fi/" ] ,
  "supermailerscript" : [ "supermailerscript.png" , "http://www.supermailer.de/" ] ,
  "stroede cmartpost" : [ "stroede-ralton.png" , "http://www.stroederalton.se/" ] ,
  "sse-unimatrix-one" : [ "1und1.png" , "http://www.1and1.co.uk/" ] ,
  "smartresponder.ru" : [ "smartresponder_ru.png" , "http://www.smartresponder.ru/" ] ,
  "stepstone mailer" : [ "stepstone.png" , "http://www.stepstone.de/" ] ,
  "sav materiel.net" : [ "materiel.png" , "http://www.materiel.net/" ] ,
  "spritmonitor.de" : [ "spritmonitor.png" , "http://www.spritmonitor.de/" ] ,
  "sonicmailer pro" : [ "sonicmailer_pro.png" , "http://www.triexa.com/" ] ,
  "share-rapid.com" : [ "share-rapid.png" , "http://share-rapid.com/" ] ,
  "scooby for beos" : [ "beos_scooby.png" , "http://sourceforge.net/projects/scooby" ] ,
  "satamatics ssas" : [ "satamatics.png" , "http://www.satamatics.com/ssas/" ] ,
  "swistak mailer" : [ "swistak.png" , "http://www.swistak.pl/" ] ,
  "smartstore.biz" : [ "smartstore.png" , "http://www.smartstore.com/" ] ,
  "sky-newsletter" : [ "sky-scripts.png" , "http://www.sky-scripts.de/" ] ,
  "sibnet webmail" : [ "sibnet.png" , "http://mail.sibnet.ru/" ] ,
  "sevsmtp mailer" : [ "sev.png" , "http://www.tools4vb.com/" ] ,
  "scouts on-line" : [ "scouts-online.png" , "http://www.scouting.nl/" ] ,
  "sharpener mail" : [ "sharpener.png" , "http://www.sharpener.com.br/" ] ,
  "sevenload mail" : [ "sevenload.png" , "http://www.sevenload.com/" ] ,
  "sysaid server" : [ "sysaid.png" , "http://www.ilient.com/" ] ,
  "store-mailer/" : [ "apple_store.png" , "http://store.apple.com/" ] ,
  "sohu web mail" : [ "sohu_com.png" , "http://www.sohu.com/" ] ,
  "sina freemail" : [ "sina_com.png" , "http://mail.sina.com.cn/" ] ,
  "system2teach" : [ "hs-fulda.png" , "http://www.system2teach.de/" ] ,
  "synergyemail" : [ "synergyemail.png" , "http://www.synergysitemanager.com/" ] ,
  "synchredible" : [ "synchredible.png" , "http://www.ascomp.de/index.php?php=products" ] ,
  "startaid.com" : [ "startaid_com.png" , "http://www.startaid.com/" ] ,
  "snood letter" : [ "snood.png" , "http://www.snoodworld.com/" ] ,
  "smartmessage" : [ "smartmessage.png" , "http://www.smartmessage.com.tr/" ] ,
  "staroffice21" : [ "staroffice21.png" , "http://www.nec.co.jp/gw/" ] ,
  "squirrelmail" : [ "squirrelmail.png" , "http://www.squirrelmail.org/" ] ,
  "spon-webmail" : [ "spiegel_online.png" , "http://www.spiegel.de/" ] ,
  "smtpjavamail" : [ "smtpjavamail.png" , "http://java.sun.com/products/javamail/" ] ,
  "sina webmail" : [ "sina_com.png" , "http://mail.sina.com.cn/" ] ,
  "simorganizer" : [ "simorganizer.png" ] ,
  "shop to date" : [ "shoptodate.png" , "http://www.shoptodate.de/" ] ,
  "serendipity/" : [ "serendipity.png" , "http://www.s9y.org/" ] ,
  "send::around" : [ "sendaround.png" , "http://www.sendaround.de/" ] ,
  "scrubby mail" : [ "scrubtheweb.png" , "http://www.scrubtheweb.com/" ] ,
  "syncbackpro" : [ "syncbackpro.png" , "http://www.2brightsparks.com/syncback/sbpro.html" ] ,
  "svn::notify" : [ "subversion.png" , "http://subversion.tigris.org/" ] ,
  "surveygizmo" : [ "surveygizmo.png" , "http://www.surveygizmo.com/" ] ,
  "surfcontrol" : [ "surfcontrol.png" , "http://www.surfcontrol.com/Default.aspx?id=357" ] ,
  "stumbleupon" : [ "stumbleupon.png" , "http://www.stumbleupon.com/" ] ,
  "streamserve" : [ "streamserve.png" , "http://www.streamserve.com/" ] ,
  "storeforyou" : [ "storeforyou.png" , "http://www.storeforyou.de/" ] ,
  "steg-mailer" : [ "stegcomputer.png" , "http://www.stegcomputer.ch/" ] ,
  "sqli mailer" : [ "sqli_com.png" , "http://www.sqli.com/" ] ,
  "specmanager" : [ "acdlabs.png" , "http://www.acdlabs.com/products/spec_lab/exp_spectra/" ] ,
  "spartoo.com" : [ "spartoo_com.png" , "http://www.spartoo.com/" ] ,
  "software602" : [ "software602.png" , "http://www.software602.com/" ] ,
  "snappermail" : [ "snappermail.png" , "http://www.snappermail.com/" ] ,
  "smartagent/" : [ "smartagent.png" ] ,
  "simplecheck" : [ "simplecheck.png" , "http://sourceforge.net/projects/simplecheck/" ] ,
  "simple mail" : [ "simple-mail.png" , "http://telega.phpnet.us/simplemail/" ] ,
  "shopexpress" : [ "shopexpress.png" , "http://www.shopexpress.info" ] ,
  "sendblaster" : [ "sendblaster.png" , "http://www.sendblaster.com/" ] ,
  "sa-smtpmail" : [ "softartisans.png" , "http://www.aspstudio.com/" ] ,
  "symbian os" : [ "symbian_os.png" , "http://www.symbian.com/" ] ,
  "su-webmail" : [ "stockholm_uni.png" , "http://www.su.se/" ] ,
  "subskrypcj" : [ "subskrypcj.png" , "http://www.subskrypcja.pl/" ] ,
  "strongmail" : [ "strongmail.png" , "http://www.strongmail.com/" ] ,
  "stringdata" : [ "post_sk.png" , "http://www.post.sk/" ] ,
  "streamsend" : [ "streamsend.png" , "http://www.streamsend.com/" ] ,
  "step ahead" : [ "stepahead.png" , "http://www.stepahead.info/" ] ,
  "staroffice" : [ "staroffice.png" , "http://www.sun.com/software/staroffice/" ] ,
  "soupermail" : [ "soupermail.png" , "http://soupermail.sourceforge.net/" ] ,
  "smtpit pro" : [ "smtpit-pro.png" , "http://www.cnsplug-ins.com/products.htm?product=smtpit%20pro" ] ,
  "smtpbeamer" : [ "smtpbeamer.png" , "http://www.dataenter.co.at/products/smtpbeamer.htm" ] ,
  "smoothwall" : [ "smoothwall.png" , "http://www.smoothwall.net/" ] ,
  "smartmail(" : [ "freebit.png" , "http://www.freebit.com/" ] ,
  "simplemail" : [ "python.png" , "http://www.python-forum.de/post-18144.html" ] ,
  "schuelervz" : [ "schuelervz.png" , "http://schuelervz.net/" ] ,
  "scenario m" : [ "scenario-m_de.png" , "http://www.scenario-m.de/" ] ,
  "satamatics" : [ "satamatics.png" , "http://www.satamatics.com/" ] ,
  "synckolab" : [ "kolab.png" , "http://www.kolab.org/" ] ,
  "swreg.org" : [ "swreg_org.png" , "http://swreg.org/" ] ,
  "swiftdove" : [ "swiftdove.png" , "http://swiftweasel.tuxfamily.org/" ] ,
  "svnmailer" : [ "subversion.png" , "http://opensource.perlig.de/svnmailer/" ] ,
  "spnetmail" : [ "spiegel_online.png" , "http://www.spiegel.de/" ] ,
  "spicebird" : [ "spicebird.png" , "http://www.spicebird.com/" ] ,
  "speedmail" : [ "speedmail.png" , "http://members.aol.com/toadbee/Programs.htm" ] ,
  "smart4web" : [ "smart4web.png" , "http://www.smart4web.cz/" ] ,
  "sendemail" : [ "sendemail.png" , "http://caspian.dotconf.net/menu/Software/SendEmail/" ] ,
  "sake mail" : [ "sake_mail.png" , "http://www.endymion.com/products/sake/" ] ,
  "syndmail" : [ "redclay.png" , "http://www.redclay.com/products/syndmail.html" ] ,
  "symantec" : [ "symantec.png" , "http://www.symantec.com/" ] ,
  "sylpheed" : [ "sylpheed.png" , "http://sylpheed.sraoss.jp/en/" ] ,
  "sun java" : [ "java.png" , "http://www.sun.com/" ] ,
  "steganos" : [ "steganos.png" , "http://www.steganos.com/" ] ,
  "stardoll" : [ "stardoll.png" , "http://www.stardoll.com/" ] ,
  "spaps.de" : [ "spaps_de.png" , "http://www.spaps.de/" ] ,
  "sogomail" : [ "sogomail.png" , "http://sogo.opengroupware.org/" ] ,
  "socratos" : [ "socratos.png" , "http://www.socratos.be/" ] ,
  "smtpsend" : [ "smtpsend.png" , "http://www.geocities.com/mdrapps/smtpsend/" ] ,
  "smtpmail" : [ "smtpmail.png" , "http://fileup.softartisans.com/fileup-276.aspx" ] ,
  "sitemail" : [ "sitemail.png" , "http://sitemail.hostway.com/" ] ,
  "sinamail" : [ "sina_com.png" , "http://mail.sina.com.cn/" ] ,
  "sev.mail" : [ "sev.png" , "http://www.tools4vb.com/software/sevmail.php" ] ,
  "sendsmtp" : [ "sendsmtp.png" , "http://www.greyware.com/software/sendsmtp/" ] ,
  "sendmail" : [ "sendmail.png" , "http://www.sendmail.org/" ] ,
  "synapse" : [ "synapse.png" , "http://synapse.ararat.cz/" ] ,
  "swwwing" : [ "swwwing.png" , "http://www.swwwing.com/" ] ,
  "sunmail" : [ "sunmail.png" , "http://www.sunmail.com/" ] ,
  "suite26" : [ "suite26.png" , "http://www.26.co.uk/" ] ,
  "studivz" : [ "studivz.png" , "http://studivz.net/" ] ,
  "spiral/" : [ "spiral.png" , "http://www.smp.ne.jp/" ] ,
  "sparrow" : [ "sparrow.png" , "http://sparrowmailapp.com/" ] ,
  "soom.cz" : [ "soom_cz.png" , "http://www.soom.cz/index.php?name=projects/mail/main" ] ,
  "sndmail" : [ "sndmail.png" , "http://www.xmailserver.org/davide.html" ] ,
  "si.mail" : [ "si_mail.png" , "http://www.simail.si/" ] ,
  "sybase" : [ "sybase.png" , "http://www.sybase.com/" ] ,
  "swi.hu" : [ "swi.png" , "http://www.swi.hu/" ] ,
  "strato" : [ "strato.png" , "http://www.strato.de/" ] ,
  "sophos" : [ "sophos.png" , "http://www.sophos.com/" ] ,
  "smtpit" : [ "smtpit.png" , "http://www.cnsplug-ins.com/products.htm?product=SMTPit" ] ,
  "skyrix" : [ "skyrix.png" , "http://www.skyrix.com/" ] ,
  "sixcms" : [ "six.png" , "http://www.six.de/" ] ,
  "siebel" : [ "oracle.png" , "http://www.oracle.com/siebel" ] ,
  "sidoko" : [ "siegel-edv_de.png" , "http://www.siegel-edv.de/" ] ,
  "scsmtp" : [ "sc-resources.png" , "http://www.sc-resources.net/" ] ,
  "scalix" : [ "scalix.png" , "http://www.scalix.com/" ] ,
  "sympa" : [ "sympa.png" , "http://www.sympa.org/" ] ,
  "swift" : [ "swiftmailer.png" , "http://www.swiftmailer.org/" ] ,
  "swaks" : [ "swaks.png" , "http://jetmore.org/john/code/#swaks" ] ,
  "sumo/" : [ "sumo.png" ] ,
  "smtpc" : [ "smtpc.png" , "http://shellscripts.org/project/smtpc" ] ,
  "smail" : [ "smail.png" , "http://www.weird.com/~woods/projects/smail.html" ] ,
  "slrn/" : [ "slrn.png" , "http://slrn.sourceforge.net/" ] ,
  "slrn " : [ "slrn.png" , "http://slrn.sourceforge.net/" ] ,
  "sharp" : [ "sharp.png" , "http://www.sharp.co.jp/" ] ,
  "setia" : [ "setia.png" , "http://www.setia.info/" ] ,
  "sesna" : [ "sesna.png" , "http://maple.snowdrift.cc/?sesna%2FV2" ] ,
  "sup/" : [ "ruby.png" , "http://sup.rubyforge.org/" ] ,
  "sap " : [ "sap.png" , "http://www.sap.com/" ] ,
  "smf" : [ "simplemachines.png" , "http://www.simplemachines.org/" ] ,
  "sk " : [ "typo3.png" , "http://www.sk-typo3.de/" ] ,
}
